@@ -119,11 +119,11 @@ class Worker:
     ) -> bool:
         try:
             task = self.task_queue.craft_task(
-                task_name=task_name if task_name else self.config.name,
                 kwargs=kwargs,
             )
 
             self.task_queue.apply_async_one(
+                task_name=task_name if task_name else self.config.name,
                 task=task,
                 priority=priority,
             )
@@ -148,7 +148,6 @@ class Worker:
 
             tasks = [
                 self.task_queue.craft_task(
-                    task_name=task_name,
                     kwargs=kwargs,
                 )
                 for kwargs in kwargs_list
@@ -244,6 +243,7 @@ class Worker:
             'executor_exception': None,
             'initialize_exception': None,
             'finalize_exception': None,
+            'executor': {},
         }
 
         try:
@@ -259,6 +259,9 @@ class Worker:
             return summary
 
         try:
+            task_start_time = time.perf_counter()
+            task_start_process_time = time.process_time()
+
             self.executor_obj.execute_tasks(
                 tasks=self.iterate_tasks(),
             )
@@ -272,18 +275,25 @@ class Worker:
             )
 
             summary['executor_exception'] = exception
-        finally:
-            try:
-                self.finalize()
-            except Exception as exception:
-                self.logger.error(
-                    msg=f'finalize has failed: {exception}',
-                )
-                summary['finalize_exception'] = exception
 
-            summary['end_time'] = datetime.datetime.utcnow()
+        try:
+            self.finalize()
+        except Exception as exception:
+            self.logger.error(
+                msg=f'finalize has failed: {exception}',
+            )
+            summary['finalize_exception'] = exception
 
-            return summary
+        total_cpu_time = time.process_time() - task_start_process_time
+        total_wall_time = time.perf_counter() - task_start_time
+        summary['end_time'] = datetime.datetime.utcnow()
+        summary['executor'] = {
+            'cpu_utilization': total_cpu_time / total_wall_time,
+            'total_wall_time': total_wall_time,
+            'total_cpu_time': total_cpu_time,
+        }
+
+        return summary
 
     def retry(
         self,
@@ -294,6 +304,7 @@ class Worker:
             raise WorkerMaxRetries()
         else:
             self.task_queue.retry(
+                task_name=self.config.name,
                 task=task,
                 priority=priority,
             )
@@ -306,6 +317,7 @@ class Worker:
         priority: str = 'NORMAL',
     ) -> None:
         self.task_queue.requeue(
+            task_name=self.config.name,
             task=task,
             priority=priority,
         )
